@@ -9,7 +9,7 @@ import sys
 import termios
 from textwrap import wrap
 import tty
-from typing import Iterable, Iterator
+from typing import Callable, Iterator
 
 from . import shell
 from .meta import scriptname
@@ -133,49 +133,6 @@ def copy_to_clipboard(clip: str) -> None:
     logger.info("Copied %s into clipboard using %s.", clip, tool)
 
 
-def get_secret(
-    key: str,
-    *key_parts: str,
-    cmd_list: Iterable[str] = None,
-    directory: str = None,
-    user: str = None,
-) -> str:
-    """Returns a secret (i.e. a password).
-
-    Args:
-        key: The key that the secret is associated with.
-        key_parts: If provided, these are treated as part of the secret key and
-          are joined with the ``key`` argument by separating each distinct key
-          part with a period.
-        cmd_list: Optional command list to use for fetching the secret (e.g.
-          ["pass", "show"], which is the default). Note: we will append the
-          ``key`` argument to this list before running.
-        directory: If provided, this directory is prepended to the beginning of
-          the ``key`` argument.
-        user: Should we use `sudo -u <user>` to run our secret retriever
-          command as that user?
-    """
-    if key_parts:
-        key = ".".join([key] + list(key_parts))
-
-    if cmd_list is None:
-        cmd_list = ["pass", "show"]
-
-    if directory is not None:
-        directory = directory.rstrip("/")
-        key = f"{directory}/{key}"
-
-    full_cmd_list = []
-    if user is not None:
-        full_cmd_list.extend(["sudo", "-u", user])
-
-    full_cmd_list.extend(cmd_list)
-    full_cmd_list.append(key)
-
-    secret, _err = shell.safe_popen(full_cmd_list).unwrap()
-    return secret
-
-
 def notify(
     *args: str, title: str = None, urgency: str = None, up: int = 0
 ) -> None:
@@ -232,3 +189,23 @@ def xtype(keys: str, *, delay: int = None) -> None:
     keys = keys.strip("\n")
 
     sp.check_call(["xdotool", "type", "--delay", str(delay), keys])
+
+
+def _color_factory(N: int) -> Callable[[str], str]:
+    def color(msg: str) -> str:
+        return "%s%s%s" % ("\033[{}m".format(N), msg, "\033[0m")
+
+    return color
+
+
+class colors:
+    """Namespace for <color>() functions."""
+
+    black = _color_factory(30)
+    blue = _color_factory(34)
+    cyan = _color_factory(36)
+    green = _color_factory(32)
+    magenta = _color_factory(35)
+    red = _color_factory(31)
+    white = _color_factory(37)
+    yellow = _color_factory(33)
